ServerBuilder

Struct ServerBuilder 

pub struct ServerBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ServerBuilder<S>

pub fn build(self) -> Server
where S: IsComplete,

Finish building and return the requested object

pub fn address(self, value: impl Into<String>) -> ServerBuilder<SetAddress<S>>
where S::Address: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_ADDRESS.

The address to bind the server to.

pub fn maybe_address( self, value: Option<impl Into<String>>, ) -> ServerBuilder<SetAddress<S>>
where S::Address: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_ADDRESS.

The address to bind the server to.

pub fn port(self, value: impl Into<u16>) -> ServerBuilder<SetPort<S>>
where S::Port: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_PORT.

The port to bind the server to.

pub fn maybe_port( self, value: Option<impl Into<u16>>, ) -> ServerBuilder<SetPort<S>>
where S::Port: IsUnset,

Optional (Some / Option setters). Default: DEFAULT_PORT.

The port to bind the server to.

pub fn info(self, value: impl Into<ServiceInfo>) -> ServerBuilder<SetInfo<S>>
where S::Info: IsUnset,

Required.

The service information.

pub fn shared_database( self, value: Arc<dyn Database>, ) -> ServerBuilder<SetSharedDatabase<S>>
where S::SharedDatabase: IsUnset,

Required.

The TES database to use for the server.

pub fn orchestrator_url( self, value: impl Into<Url>, ) -> ServerBuilder<SetOrchestratorUrl<S>>
where S::OrchestratorUrl: IsUnset,

Required.

The Planetary orchestrator service URL.

pub fn orchestrator_api_key( self, value: impl Into<SecretString>, ) -> ServerBuilder<SetOrchestratorApiKey<S>>
where S::OrchestratorApiKey: IsUnset,

Required.

The Planetary orchestrator service API key.

Source

impl<S: State> ServerBuilder<S>

pub fn database( self, database: impl Database + 'static, ) -> ServerBuilder<SetSharedDatabase<S>>
where S::SharedDatabase: IsUnset,

The TES database to use for the server.

This is a convenience method for setting the shared database server from any type that implements Database.