pub struct ServerBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> ServerBuilder<S>
impl<S: State> ServerBuilder<S>
Sourcepub fn build(self) -> Serverwhere
S: IsComplete,
pub fn build(self) -> Serverwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn address(self, value: impl Into<String>) -> ServerBuilder<SetAddress<S>>where
S::Address: IsUnset,
pub fn address(self, value: impl Into<String>) -> ServerBuilder<SetAddress<S>>where
S::Address: IsUnset,
Sourcepub fn maybe_address(
self,
value: Option<impl Into<String>>,
) -> ServerBuilder<SetAddress<S>>where
S::Address: IsUnset,
pub fn maybe_address(
self,
value: Option<impl Into<String>>,
) -> ServerBuilder<SetAddress<S>>where
S::Address: IsUnset,
Sourcepub fn port(self, value: impl Into<u16>) -> ServerBuilder<SetPort<S>>where
S::Port: IsUnset,
pub fn port(self, value: impl Into<u16>) -> ServerBuilder<SetPort<S>>where
S::Port: IsUnset,
Sourcepub fn maybe_port(
self,
value: Option<impl Into<u16>>,
) -> ServerBuilder<SetPort<S>>where
S::Port: IsUnset,
pub fn maybe_port(
self,
value: Option<impl Into<u16>>,
) -> ServerBuilder<SetPort<S>>where
S::Port: IsUnset,
Sourcepub fn info(self, value: impl Into<ServiceInfo>) -> ServerBuilder<SetInfo<S>>where
S::Info: IsUnset,
pub fn info(self, value: impl Into<ServiceInfo>) -> ServerBuilder<SetInfo<S>>where
S::Info: IsUnset,
Required.
The service information.
Required.
The TES database to use for the server.
Sourcepub fn orchestrator_url(
self,
value: impl Into<Url>,
) -> ServerBuilder<SetOrchestratorUrl<S>>where
S::OrchestratorUrl: IsUnset,
pub fn orchestrator_url(
self,
value: impl Into<Url>,
) -> ServerBuilder<SetOrchestratorUrl<S>>where
S::OrchestratorUrl: IsUnset,
Required.
The Planetary orchestrator service URL.
Sourcepub fn orchestrator_api_key(
self,
value: impl Into<SecretString>,
) -> ServerBuilder<SetOrchestratorApiKey<S>>where
S::OrchestratorApiKey: IsUnset,
pub fn orchestrator_api_key(
self,
value: impl Into<SecretString>,
) -> ServerBuilder<SetOrchestratorApiKey<S>>where
S::OrchestratorApiKey: IsUnset,
Required.
The Planetary orchestrator service API key.
Sourceimpl<S: State> ServerBuilder<S>
impl<S: State> ServerBuilder<S>
Sourcepub fn database(
self,
database: impl Database + 'static,
) -> ServerBuilder<SetSharedDatabase<S>>where
S::SharedDatabase: IsUnset,
pub fn database(
self,
database: impl Database + 'static,
) -> ServerBuilder<SetSharedDatabase<S>>where
S::SharedDatabase: IsUnset,
The TES database to use for the server.
This is a convenience method for setting the shared database server
from any type that implements Database.